Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/facet/org.eclipse.papyrus.emf.facet.efacet.catalog/src/org/eclipse/papyrus/emf/facet/efacet/catalog/efacetcatalog/util/EfacetcatalogAdapterFactory.java')
-rw-r--r--plugins/facet/org.eclipse.papyrus.emf.facet.efacet.catalog/src/org/eclipse/papyrus/emf/facet/efacet/catalog/efacetcatalog/util/EfacetcatalogAdapterFactory.java24
1 files changed, 12 insertions, 12 deletions
diff --git a/plugins/facet/org.eclipse.papyrus.emf.facet.efacet.catalog/src/org/eclipse/papyrus/emf/facet/efacet/catalog/efacetcatalog/util/EfacetcatalogAdapterFactory.java b/plugins/facet/org.eclipse.papyrus.emf.facet.efacet.catalog/src/org/eclipse/papyrus/emf/facet/efacet/catalog/efacetcatalog/util/EfacetcatalogAdapterFactory.java
index c677081027b..64d1399c3e0 100644
--- a/plugins/facet/org.eclipse.papyrus.emf.facet.efacet.catalog/src/org/eclipse/papyrus/emf/facet/efacet/catalog/efacetcatalog/util/EfacetcatalogAdapterFactory.java
+++ b/plugins/facet/org.eclipse.papyrus.emf.facet.efacet.catalog/src/org/eclipse/papyrus/emf/facet/efacet/catalog/efacetcatalog/util/EfacetcatalogAdapterFactory.java
@@ -11,22 +11,22 @@
* Nicolas Guyomar (Mia-Software) - Implementation
*
*/
-package org.eclipse.emf.facet.efacet.catalog.efacetcatalog.util;
+package org.eclipse.papyrus.emf.facet.efacet.catalog.efacetcatalog.util;
import org.eclipse.emf.common.notify.Adapter;
import org.eclipse.emf.common.notify.Notifier;
import org.eclipse.emf.common.notify.impl.AdapterFactoryImpl;
import org.eclipse.emf.ecore.EObject;
-import org.eclipse.emf.facet.efacet.catalog.efacetcatalog.EfacetcatalogPackage;
-import org.eclipse.emf.facet.efacet.catalog.efacetcatalog.FacetSetCatalog;
-import org.eclipse.emf.facet.efacet.catalog.efacetcatalog.QuerySetCatalog;
-import org.eclipse.emf.facet.util.emf.catalog.Catalog;
+import org.eclipse.papyrus.emf.facet.efacet.catalog.efacetcatalog.EfacetcatalogPackage;
+import org.eclipse.papyrus.emf.facet.efacet.catalog.efacetcatalog.FacetSetCatalog;
+import org.eclipse.papyrus.emf.facet.efacet.catalog.efacetcatalog.QuerySetCatalog;
+import org.eclipse.papyrus.emf.facet.util.emf.catalog.Catalog;
/**
* <!-- begin-user-doc --> The <b>Adapter Factory</b> for the model. It provides an adapter
* <code>createXXX</code> method for each class of the model. <!-- end-user-doc -->
*
- * @see org.eclipse.emf.facet.efacet.catalog.efacetcatalog.EfacetcatalogPackage
+ * @see org.eclipse.papyrus.emf.facet.efacet.catalog.efacetcatalog.EfacetcatalogPackage
* @generated
* @deprecated cf. https://bugs.eclipse.org/bugs/show_bug.cgi?id=373672
*/
@@ -112,13 +112,13 @@ public class EfacetcatalogAdapterFactory extends AdapterFactoryImpl {
/**
* Creates a new adapter for an object of class '{@link org.eclipse.emf.facet.efacet.catalog.efacetcatalog.QuerySetCatalog <em>Query Set Catalog</em>}'.
* <!-- begin-user-doc -->
* This default implementation returns null so that we can easily ignore cases;
* it's useful to ignore a case when inheritance will catch all the cases anyway.
* <!-- end-user-doc -->
* @return the new adapter.
- * @see org.eclipse.emf.facet.efacet.catalog.efacetcatalog.QuerySetCatalog
+ * @see org.eclipse.papyrus.emf.facet.efacet.catalog.efacetcatalog.QuerySetCatalog
* @generated
*/
public Adapter createQuerySetCatalogAdapter() {
@@ -126,13 +126,13 @@ public class EfacetcatalogAdapterFactory extends AdapterFactoryImpl {
}
/**
* Creates a new adapter for an object of class '{@link org.eclipse.emf.facet.efacet.catalog.efacetcatalog.FacetSetCatalog <em>Facet Set Catalog</em>}'.
* <!-- begin-user-doc -->
* This default implementation returns null so that we can easily ignore cases;
* it's useful to ignore a case when inheritance will catch all the cases anyway.
* <!-- end-user-doc -->
* @return the new adapter.
- * @see org.eclipse.emf.facet.efacet.catalog.efacetcatalog.FacetSetCatalog
+ * @see org.eclipse.papyrus.emf.facet.efacet.catalog.efacetcatalog.FacetSetCatalog
* @generated
*/
public Adapter createFacetSetCatalogAdapter() {
@@ -140,13 +140,13 @@ public class EfacetcatalogAdapterFactory extends AdapterFactoryImpl {
}
/**
* Creates a new adapter for an object of class '{@link org.eclipse.emf.facet.util.emf.catalog.Catalog <em>Catalog</em>}'.
* <!-- begin-user-doc -->
* This default implementation returns null so that we can easily ignore cases;
* it's useful to ignore a case when inheritance will catch all the cases anyway.
* <!-- end-user-doc -->
* @return the new adapter.
- * @see org.eclipse.emf.facet.util.emf.catalog.Catalog
+ * @see org.eclipse.papyrus.emf.facet.util.emf.catalog.Catalog
* @generated
*/
public Adapter createCatalogAdapter() {
@@ -112,13 +112,13 @@ public class EfacetcatalogAdapterFactory extends AdapterFactoryImpl {
/**
- * Creates a new adapter for an object of class '{@link org.eclipse.emf.facet.efacet.catalog.efacetcatalog.QuerySetCatalog <em>Query Set Catalog</em>}'.
+ * Creates a new adapter for an object of class '{@link org.eclipse.papyrus.emf.facet.efacet.catalog.efacetcatalog.QuerySetCatalog <em>Query Set Catalog</em>}'.
* <!-- begin-user-doc -->
* This default implementation returns null so that we can easily ignore cases;
@@ -126,13 +126,13 @@ public class EfacetcatalogAdapterFactory extends AdapterFactoryImpl {
}
/**
- * Creates a new adapter for an object of class '{@link org.eclipse.emf.facet.efacet.catalog.efacetcatalog.FacetSetCatalog <em>Facet Set Catalog</em>}'.
+ * Creates a new adapter for an object of class '{@link org.eclipse.papyrus.emf.facet.efacet.catalog.efacetcatalog.FacetSetCatalog <em>Facet Set Catalog</em>}'.
* <!-- begin-user-doc -->
* This default implementation returns null so that we can easily ignore cases;
@@ -140,13 +140,13 @@ public class EfacetcatalogAdapterFactory extends AdapterFactoryImpl {
}
/**
- * Creates a new adapter for an object of class '{@link org.eclipse.emf.facet.util.emf.catalog.Catalog <em>Catalog</em>}'.
+ * Creates a new adapter for an object of class '{@link org.eclipse.papyrus.emf.facet.util.emf.catalog.Catalog <em>Catalog</em>}'.
* <!-- begin-user-doc -->
* This default implementation returns null so that we can easily ignore cases;

Back to the top